Fake Blender Python API module collection: fake-bpy-module
==========================================================

fake-bpy-module is the collections of the fake Blender Python API
modules for the code completion in commonly used IDEs.

*Note: The similar project for Blender Game Engine (BGE) is availabled
on `fake-bge-module <https://github.com/nutti/fake-bge-module>`__ which
targets `UPBGE <https://upbge.org/>`__.*

.. figure:: https://raw.githubusercontent.com/nutti/fake-bpy-module/master/docs/images/fake-bpy-module_thumbnail.png
   :alt: 

Requirements
------------

fake-bpy-module uses typing module and type hints availabled from Python
3.7. Check your Python version is >= 3.7.

Install
-------

fake-bpy-module can be installed via a pip package, or pre-generated
modules. You can also generate and install modules manually.

Install via pip package
~~~~~~~~~~~~~~~~~~~~~~~

| fake-bpy-module is registered to PyPI.
| You can install it as a pip package.

.. code:: sh

    pip install fake-bpy-module-<version>

If you install fake-bpy-module for Blender 2.8, run below command.

.. code:: sh

    pip install fake-bpy-module-2.80

Supported Blender Version
^^^^^^^^^^^^^^^^^^^^^^^^^

+-----------+--------------------------------------------------+
| Version   | PyPI                                             |
+===========+==================================================+
| 2.78      | https://pypi.org/project/fake-bpy-module-2.78/   |
+-----------+--------------------------------------------------+
| 2.79      | https://pypi.org/project/fake-bpy-module-2.79/   |
+-----------+--------------------------------------------------+
| 2.80      | https://pypi.org/project/fake-bpy-module-2.80/   |
+-----------+--------------------------------------------------+
| 2.81      | https://pypi.org/project/fake-bpy-module-2.81/   |
+-----------+--------------------------------------------------+
| 2.82      | https://pypi.org/project/fake-bpy-module-2.82/   |
+-----------+--------------------------------------------------+
| 2.83      | https://pypi.org/project/fake-bpy-module-2.83/   |
+-----------+--------------------------------------------------+

Install via pre-generated modules
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Download Pre-generated modules from `Release
page <https://github.com/nutti/fake-bpy-module/releases>`__.

The process of installation via pre-generated modules is different by
IDE. See the installation processes as follows for detail.

-  `PyCharm <docs/setup_pycharm.md>`__
-  `Visual Studio Code <docs/setup_visual_studio_code.md>`__
-  `All Text Editor (Install as Python
   module) <docs/setup_all_text_editor.md>`__

Generate Modules Manually
~~~~~~~~~~~~~~~~~~~~~~~~~

You can also generate modules manually. See `Generate
Module <https://github.com/nutti/fake-bpy-module/blob/master/docs/generate_modules.md>`__
for detail.

Bug report / Feature request / Disscussions
-------------------------------------------

If you want to report bug, request features or discuss about this
add-on, see
`ISSUES.md <https://github.com/nutti/fake-bpy-module/blob/master/ISSUES.md>`__.

Contribution
------------

If you want to contribute to this project, see
`CONTRIBUTING.md <https://github.com/nutti/fake-bpy-module/blob/master/CONTRIBUTING.md>`__.
